How to contribute — Modoboa 1.7.4 documentation

### Navigation

- index
- next |
- previous |
- Modoboa 1.7.4 documentation »

# How to contribute

Contributions are always welcome. If you want to submit a patch, please respect the following rules:

- Open a pull request on the appropriate repository
- Respect PEP8
- Document your patch and respect PEP 257
- Add unit tests and make sure the global coverage does not decrease

If all those steps are validated, your contribution will generally be integrated.

## Table of contents

- Useful tips
- Create a new plugin

### Navigation

- index
- next |
- previous |
- Modoboa 1.7.4 documentation »